Documentation
¶
Index ¶
- func NewRequest(method string, urs string, body io.Reader, tm time.Time, ...) (*http.Request, error)
- func SetLogger(l Logger)
- type Auth
- type Error
- type LogLevel
- type Logger
- type Message
- type MessagesResponse
- type Metadata
- type Response
- type SigchainResponse
- type SigchainsResponse
- type UserPublicKeyResponse
- type UserPublicKeysResponse
- type UsersResponse
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Error ¶
type Error struct {
Message string `json:"message,omitempty"`
Status int `json:"status,omitempty"`
}
Error ...
type Logger ¶
type Logger interface {
Debugf(format string, args ...interface{})
Infof(format string, args ...interface{})
Warningf(format string, args ...interface{})
Errorf(format string, args ...interface{})
}
Logger interface used in this package
type MessagesResponse ¶
type MessagesResponse struct {
Messages []*Message `json:"messages"`
Metadata map[string]*Metadata `json:"md,omitempty"`
Recipient keyup.ID `json:"recipient"`
Version string `json:"version"`
}
MessagesResponse is the response from messages.
func (MessagesResponse) MetadataFor ¶
func (r MessagesResponse) MetadataFor(msg *Message) *Metadata
MetadataFor returns metadata for Message.
type SigchainResponse ¶
type SigchainResponse struct {
Metadata map[string]*Metadata `json:"md,omitempty"`
Statements []*keyup.Statement `json:"statements"`
UserPublicKey *keyup.UserPublicKey `json:"upk"`
}
SigchainResponse is the response format for a Sigchain request.
func (SigchainResponse) MetadataFor ¶
func (r SigchainResponse) MetadataFor(st *keyup.Statement) *Metadata
MetadataFor returns metadata for Signed.
type SigchainsResponse ¶
type SigchainsResponse struct {
Metadata map[string]*Metadata `json:"md,omitempty"`
Statements []*keyup.Statement `json:"statements"`
Version string `json:"version"`
}
SigchainsResponse is the response format for a listing all sigchain statements.
func (SigchainsResponse) MetadataFor ¶
func (r SigchainsResponse) MetadataFor(st *keyup.Statement) *Metadata
MetadataFor returns metadata for Signed.
type UserPublicKeyResponse ¶
type UserPublicKeyResponse struct {
Metadata *Metadata `json:"md,omitempty"`
UserPublicKey *keyup.UserPublicKey `json:"upk"`
}
UserPublicKeyResponse is the response format for a UserPublicKey request.
type UserPublicKeysResponse ¶
type UserPublicKeysResponse struct {
Metadata map[string]*Metadata `json:"md,omitempty"`
UserPublicKeys []*keyup.UserPublicKey `json:"upks"`
Version string `json:"version"`
}
UserPublicKeysResponse is the response format for a UserPublicKeys request.
func (UserPublicKeysResponse) MetadataFor ¶
func (r UserPublicKeysResponse) MetadataFor(upk *keyup.UserPublicKey) *Metadata
MetadataFor returns metadata for UserPublicKey.
type UsersResponse ¶
UsersResponse ...
Click to show internal directories.
Click to hide internal directories.